@@ -16,7 +16,7 @@ class ConnectionConfig:
 
     @staticmethod
     def _domain():
-        return os.getenv("AGENTBOX_DOMAIN", "agentbox.lingyiwanwu.net")
+        return os.getenv("AGENTBOX_DOMAIN", "agentbox.space")
 
     @staticmethod
     def _debug():
@@ -60,7 +60,7 @@ class ConnectionConfig:
             self.request_timeout = REQUEST_TIMEOUT
 
         self.api_url = (
-            "http://localhost:3000" if self.debug else f"https://api-{self.domain}"
+            "http://localhost:3000" if self.debug else f"https://api.{self.domain}"
         )
 
     @staticmethod
